@@ -15,7 +15,7 @@ mix.compnorm <- function(x, g, model, type = "alr") {
   n <- dim(x)[1]  ## sample size
 
   if (type == "alr") {
-    y <- log(x[, -p]/x[, p])
+    y <- log(x[, -1]/x[, 1])
   } else {
     y0 <- log(x)
     y1 <- y0 - Rfast::rowmeans( y0 )
@@ -24,15 +24,15 @@ mix.compnorm <- function(x, g, model, type = "alr") {
 
   mod <- mixture::gpcm(y, G = g, mnames = model, start = 0, atol = 0.01)
   param <- mod$gpar
-  mu <- matrix(nrow = g, ncol = length(param[[1]]$mu))
-  su <- array( dim = c( length(param[[1]]$mu), length(param[[1]]$mu), g ) )
+  mu <- matrix(nrow = g, ncol = length( param[[ 1 ]]$mu) )
+  su <- array( dim = c( length(param[[ 1 ]]$mu), length(param[[ 1 ]]$mu), g ) )
 
   for ( i in 1:g ) {
     mu[i, ] <- param[[ i ]]$mu  ## mean vector of each component
     su[, , i] <- param[[ i ]]$sigma  ## covariance of each component
   }
   prob <- param$pi  ## mixing probability of each component
-  colnames(mu) <- colnames(su) <- colnames(y)
+
   ta <- matrix(nrow = n, ncol = g)
   for (j in 1:g)   ta[, j] <-  - 0.5 * log( det(2 * pi * su[, , j]) ) - 0.5 * Rfast::mahala(y, mu[j, ], su[, , j])
   probexpta <- prob * exp(ta)
